==> nsafirstlibrary-1.0.0.tgz: package/resources/payments.js <==
'use strict';

// Include global module
var globals = require('../global')

//Declare token
var token;

//Declare url
var url;

module.exports = {

  //List payments method request
  getPayments: function (path, host, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + currentObject.state.token;

    //Set request
    globals.https.get(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  },

  getPaymentsWithHash: function (path, host, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + currentObject.state.token;

    //Set request
    globals.https.post(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .send(requestData)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  },

  //List payments batches method request
  getPaymentsBatches: function (path, host, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + currentObject.state.token;

    //Set request
    globals.https.get(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  },

  //List payments calls method request
  getPaymentsCalls: function (path, host, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + currentObject.state.token;

    //Set request
    globals.https.get(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  }

}

==> nsafirstlibrary-2.0.0.tgz: package/resources/payments.js <==
'use strict';

// Include global module
var globals = require('../global')

//Declare url
var url;

module.exports = {

  //List payments method request
  getPayments: function (path, host, token, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + token;

    //Set request
    globals.https.get(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  },

  getPaymentsWithHash: function (path, host, token, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + token;

    //Set request
    globals.https.post(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .send(requestData)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  },

  //List payments batches method request
  getPaymentsBatches: function (path, host, token, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + token;

    //Set request
    globals.https.get(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  },

  //List payments calls method request
  getPaymentsCalls: function (path, host, token, currentObject, success) {

    // Assign Complete url
    url = host + path;

    //Define Bearer authorization
    token = 'Bearer ' + token;

    //Set request
    globals.https.get(url)
      .set('Content-Type', 'application/json')
      .set('Authorization', token)
      .set('latitude', currentObject.state.latitude)
      .set('longitude', currentObject.state.longitude)
      .end(function (error, response) {
        if (response)
          success(response.body, JSON.parse(response.statusCode), currentObject);
        else
          success(globals.errBody, globals.errStatusCode, currentObject);
      })
  }

}
